@@ -74,8 +74,8 @@ public interface BookKeeperServerStats {
     String WATCHER_SCOPE = "bookie_watcher";
     String REPLACE_BOOKIE_TIME = "REPLACE_BOOKIE_TIME";
     String NEW_ENSEMBLE_TIME = "NEW_ENSEMBLE_TIME";
-    String FAILED_TO_RESOLVE_NETWORK_LOCATION_COUNTER = "FAILED_TO_RESOLVE_NETWORK_LOCATION_COUNTER";
-    String ENSEMBLE_NOT_ADHERING_TO_PLACEMENT_POLICY_COUNTER = "ENSEMBLE_NOT_ADHERING_TO_PLACEMENT_POLICY_COUNTER";
+    String FAILED_TO_RESOLVE_NETWORK_LOCATION_COUNT = "FAILED_TO_RESOLVE_NETWORK_LOCATION_TOTAL";
+    String ENSEMBLE_NOT_ADHERING_TO_PLACEMENT_POLICY_COUNT = "ENSEMBLE_NOT_ADHERING_TO_PLACEMENT_POLICY_TOTAL";
 
     // Bookie Quarantine Stats
     String BOOKIE_QUARANTINE = "BOOKIE_QUARANTINE";
@@ -86,7 +86,6 @@ public interface BookKeeperServerStats {
     String BOOKIE_RECOVERY_ADD_ENTRY = "BOOKIE_RECOVERY_ADD_ENTRY";
     String BOOKIE_READ_ENTRY = "BOOKIE_READ_ENTRY";
     String BOOKIE_FORCE_LEDGER = "BOOKIE_FORCE_LEDGER";
-    String BOOKIE_READ_LAST_CONFIRMED = "BOOKIE_READ_LAST_CONFIRMED";
     String BOOKIE_ADD_ENTRY_BYTES = "BOOKIE_ADD_ENTRY_BYTES";
     String BOOKIE_READ_ENTRY_BYTES = "BOOKIE_READ_ENTRY_BYTES";
     String BOOKIE_GET_LIST_OF_ENTRIES_OF_LEDGER = "BOOKIE_GET_LIST_OF_ENTRIES_OF_LEDGER";
@@ -108,12 +107,8 @@ public interface BookKeeperServerStats {
     String JOURNAL_FORCE_LEDGER = "JOURNAL_FORCE_LEDGER";
     String JOURNAL_SYNC = "JOURNAL_SYNC";
     String JOURNAL_FORCE_WRITE_ENQUEUE = "JOURNAL_FORCE_WRITE_ENQUEUE";
-    String JOURNAL_MEM_ADD_ENTRY = "JOURNAL_MEM_ADD_ENTRY";
-    String JOURNAL_PREALLOCATION = "JOURNAL_PREALLOCATION";
-    String JOURNAL_FORCE_WRITE_LATENCY = "JOURNAL_FORCE_WRITE_LATENCY";
     String JOURNAL_FORCE_WRITE_BATCH_ENTRIES = "JOURNAL_FORCE_WRITE_BATCH_ENTRIES";
     String JOURNAL_FORCE_WRITE_BATCH_BYTES = "JOURNAL_FORCE_WRITE_BATCH_BYTES";
-    String JOURNAL_FORCE_WRITE_GROUPING_FAILURES = "JOURNAL_FORCE_WRITE_GROUPING_FAILURES";
     String JOURNAL_FLUSH_LATENCY = "JOURNAL_FLUSH_LATENCY";
     String JOURNAL_QUEUE_LATENCY = "JOURNAL_QUEUE_LATENCY";
     String JOURNAL_QUEUE_MAX_SIZE = "JOURNAL_QUEUE_MAX_SIZE";
@@ -148,24 +143,21 @@ public interface BookKeeperServerStats {
     String LEDGER_CACHE_MISS = "LEDGER_CACHE_MISS";
 
     // Compaction/Garbage Collection Related Counters
-    String ACTIVE_ENTRY_LOG_COUNT = "ACTIVE_ENTRY_LOG_COUNT";
+    String ACTIVE_ENTRY_LOG_COUNT = "ACTIVE_ENTRY_LOG_TOTAL";
     String ACTIVE_ENTRY_LOG_SPACE_BYTES = "ACTIVE_ENTRY_LOG_SPACE_BYTES";
     String RECLAIMED_COMPACTION_SPACE_BYTES = "RECLAIMED_COMPACTION_SPACE_BYTES";
     String RECLAIMED_DELETION_SPACE_BYTES = "RECLAIMED_DELETION_SPACE_BYTES";
     String THREAD_RUNTIME = "THREAD_RUNTIME";
-    String MAJOR_COMPACTION_COUNT = "MAJOR_COMPACTION_COUNT";
-    String MINOR_COMPACTION_COUNT = "MINOR_COMPACTION_COUNT";
-    String ACTIVE_LEDGER_COUNT = "ACTIVE_LEDGER_COUNT";
-    String DELETED_LEDGER_COUNT = "DELETED_LEDGER_COUNT";
+    String MAJOR_COMPACTION_COUNT = "MAJOR_COMPACTION_TOTAL";
+    String MINOR_COMPACTION_COUNT = "MINOR_COMPACTION_TOTAL";
+    String ENTRY_LOCATION_COMPACTION_COUNT = "ENTRY_LOCATION_COMPACTION_TOTAL";
+    String ACTIVE_LEDGER_COUNT = "ACTIVE_LEDGER_TOTAL";
+    String DELETED_LEDGER_COUNT = "DELETED_LEDGER_TOTAL";
 
     // Index Related Counters
     String INDEX_INMEM_ILLEGAL_STATE_RESET = "INDEX_INMEM_ILLEGAL_STATE_RESET";
     String INDEX_INMEM_ILLEGAL_STATE_DELETE = "INDEX_INMEM_ILLEGAL_STATE_DELETE";
     String JOURNAL_FORCE_WRITE_QUEUE_SIZE = "JOURNAL_FORCE_WRITE_QUEUE_SIZE";
-    String JOURNAL_CB_QUEUE_SIZE = "JOURNAL_CB_QUEUE_SIZE";
-    String CB_THREAD_POOL_QUEUE_SIZE = "CB_THREAD_POOL_QUEUE_SIZE";
-    String JOURNAL_CB_QUEUED_LATENCY = "JOURNAL_CB_QUEUED_LATENCY";
-    String JOURNAL_NUM_FORCE_WRITES = "JOURNAL_NUM_FORCE_WRITES";
     String JOURNAL_NUM_FLUSH_EMPTY_QUEUE = "JOURNAL_NUM_FLUSH_EMPTY_QUEUE";
     String JOURNAL_NUM_FLUSH_MAX_OUTSTANDING_BYTES = "JOURNAL_NUM_FLUSH_MAX_OUTSTANDING_BYTES";
     String JOURNAL_NUM_FLUSH_MAX_WAIT = "JOURNAL_NUM_FLUSH_MAX_WAIT";
@@ -182,10 +174,7 @@ public interface BookKeeperServerStats {
 
     // Gauge
     String NUM_INDEX_PAGES = "NUM_INDEX_PAGES";
-    String NUM_OPEN_LEDGERS = "NUM_OPEN_LEDGERS";
-    String JOURNAL_FORCE_WRITE_GROUPING_COUNT = "JOURNAL_FORCE_WRITE_GROUPING_COUNT";
-    String NUM_PENDING_READ = "NUM_PENDING_READ";
-    String NUM_PENDING_ADD = "NUM_PENDING_ADD";
+    String JOURNAL_FORCE_WRITE_GROUPING_COUNT = "JOURNAL_FORCE_WRITE_GROUPING_TOTAL";
 
     // LedgerDirs Stats
     String LD_LEDGER_SCOPE = "ledger";
