@@ -198,6 +198,11 @@ public class BookieStateManager implements StateManager {
         return forceReadOnly.get();
     }
 
+    @Override
+    public boolean isReadOnlyModeEnabled() {
+        return conf.isReadOnlyModeEnabled();
+    }
+
     @Override
     public boolean isAvailableForHighPriorityWrites() {
         return availableForHighPriorityWrites;
