@@ -21,14 +21,13 @@
 
 package org.apache.bookkeeper.bookie;
 
-import static org.apache.bookkeeper.bookie.Bookie.METAENTRY_ID_FENCE_KEY;
+import static org.apache.bookkeeper.bookie.BookieImpl.METAENTRY_ID_FENCE_KEY;
 
-import com.google.common.util.concurrent.SettableFuture;
 import io.netty.buffer.ByteBuf;
 import io.netty.buffer.Unpooled;
 import java.io.IOException;
 import java.util.PrimitiveIterator.OfLong;
-
+import java.util.concurrent.CompletableFuture;
 import org.apache.bookkeeper.common.util.Watcher;
 
 /**
@@ -66,19 +65,20 @@ public abstract class LedgerDescriptor {
     abstract long getLedgerId();
 
     abstract boolean setFenced() throws IOException;
-    abstract boolean isFenced() throws IOException;
+    abstract boolean isFenced() throws IOException, BookieException;
     /**
      * When we fence a ledger, we need to first set ledger to fenced state in memory and
      * then log the fence entry in Journal so that we can rebuild the state.
      *
      * <p>We should satisfy the future only after we complete logging fence entry in Journal
+     * @return
      */
-    abstract SettableFuture<Boolean> fenceAndLogInJournal(Journal journal) throws IOException;
+    abstract CompletableFuture<Boolean> fenceAndLogInJournal(Journal journal) throws IOException;
 
     abstract long addEntry(ByteBuf entry) throws IOException, BookieException;
-    abstract ByteBuf readEntry(long entryId) throws IOException;
+    abstract ByteBuf readEntry(long entryId) throws IOException, BookieException;
 
-    abstract long getLastAddConfirmed() throws IOException;
+    abstract long getLastAddConfirmed() throws IOException, BookieException;
     abstract boolean waitForLastAddConfirmedUpdate(long previousLAC,
                                                    Watcher<LastAddConfirmedUpdateNotification> watcher)
         throws IOException;
@@ -87,7 +87,7 @@ public abstract class LedgerDescriptor {
 
     abstract void setExplicitLac(ByteBuf entry) throws IOException;
 
-    abstract  ByteBuf getExplicitLac() throws IOException;
+    abstract  ByteBuf getExplicitLac() throws IOException, BookieException;
 
     abstract OfLong getListOfEntriesOfLedger(long ledgerId) throws IOException;
 }
