@@ -1,4 +1,4 @@
-/**
+/*
  * Licensed to the Apache Software Foundation (ASF) under one
  * or more contributor license agreements.  See the NOTICE file
  * distributed with this work for additional information
@@ -20,14 +20,12 @@ package org.apache.bookkeeper.client;
 import com.google.common.annotations.VisibleForTesting;
 import com.google.common.base.MoreObjects;
 import com.google.common.collect.ImmutableMap;
-
 import io.netty.util.Recycler;
 import io.netty.util.Recycler.Handle;
-
 import java.util.Arrays;
 import java.util.BitSet;
 import java.util.Map;
-
+import lombok.Getter;
 import org.apache.bookkeeper.net.BookieId;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
@@ -41,6 +39,7 @@ import org.slf4j.LoggerFactory;
  */
 public class RoundRobinDistributionSchedule implements DistributionSchedule {
     private static final Logger LOG = LoggerFactory.getLogger(RoundRobinDistributionSchedule.class);
+    @Getter
     private final int writeQuorumSize;
     private final int ackQuorumSize;
     private final int ensembleSize;
@@ -56,6 +55,11 @@ public class RoundRobinDistributionSchedule implements DistributionSchedule {
         return WriteSetImpl.create(ensembleSize, writeQuorumSize, entryId);
     }
 
+    @Override
+    public int getWriteSetBookieIndex(long entryId, int writeSetIndex) {
+        return (int) (entryId + writeSetIndex) % ensembleSize;
+    }
+
     @Override
     public WriteSet getEnsembleSet(long entryId) {
         // for long poll reads and force ledger , we are trying all the bookies in the ensemble
@@ -421,12 +425,13 @@ public class RoundRobinDistributionSchedule implements DistributionSchedule {
 
     @Override
     public boolean hasEntry(long entryId, int bookieIndex) {
-        WriteSet w = getWriteSet(entryId);
-        try {
-            return w.contains(bookieIndex);
-        } finally {
-            w.recycle();
+        for (int w = 0; w < writeQuorumSize; w++) {
+            if (bookieIndex == getWriteSetBookieIndex(entryId, w)) {
+                return true;
+            }
         }
+
+        return false;
     }
 
     @Override
