@@ -183,6 +183,7 @@ public abstract class AbstractConfiguration<T extends AbstractConfiguration>
     protected static final String ALLOCATOR_POOLING_CONCURRENCY = "allocatorPoolingConcurrency";
     protected static final String ALLOCATOR_OOM_POLICY = "allocatorOutOfMemoryPolicy";
     protected static final String ALLOCATOR_LEAK_DETECTION_POLICY = "allocatorLeakDetectionPolicy";
+    protected static final String ALLOCATOR_EXIT_ON_OUT_OF_MEMORY = "allocatorExitOnOutOfMemory";
 
     // option to limit stats logging
     public static final String LIMIT_STATS_LOGGING = "limitStatsLogging";
@@ -1156,6 +1157,15 @@ public abstract class AbstractConfiguration<T extends AbstractConfiguration>
         return getThis();
     }
 
+    public T setExitOnOutOfMemory(boolean exitOnOutOfMemory) {
+        this.setProperty(ALLOCATOR_EXIT_ON_OUT_OF_MEMORY, exitOnOutOfMemory);
+        return getThis();
+    }
+
+    public boolean exitOnOutOfMemory() {
+        return getBoolean(ALLOCATOR_EXIT_ON_OUT_OF_MEMORY, false);
+    }
+
     /**
      * Return whether the busy-wait is enabled for BookKeeper and Netty IO threads.
      *
