@@ -1,4 +1,4 @@
-/**
+/*
  * Licensed to the Apache Software Foundation (ASF) under one
  * or more contributor license agreements.  See the NOTICE file
  * distributed with this work for additional information
@@ -18,9 +18,7 @@
 package org.apache.bookkeeper.meta;
 
 import com.google.common.annotations.VisibleForTesting;
-
 import io.netty.util.concurrent.DefaultThreadFactory;
-
 import java.io.IOException;
 import java.util.HashSet;
 import java.util.List;
@@ -35,7 +33,6 @@ import java.util.concurrent.Executors;
 import java.util.concurrent.ScheduledExecutorService;
 import java.util.concurrent.ThreadLocalRandom;
 import java.util.concurrent.TimeUnit;
-
 import org.apache.bookkeeper.client.BKException;
 import org.apache.bookkeeper.client.LedgerMetadataBuilder;
 import org.apache.bookkeeper.client.api.LedgerMetadata;
@@ -108,10 +105,8 @@ public abstract class AbstractZkLedgerManager implements LedgerManager, Watcher
                 }
                 readLedgerMetadata(ledgerId, AbstractZkLedgerManager.this)
                     .whenComplete((metadata, exception) -> handleMetadata(metadata, exception));
-            } else {
-                if (LOG.isDebugEnabled()) {
-                    LOG.debug("Ledger metadata listener for ledger {} is already removed.", ledgerId);
-                }
+            } else if (LOG.isDebugEnabled()) {
+                LOG.debug("Ledger metadata listener for ledger {} is already removed.", ledgerId);
             }
         }
 
@@ -220,7 +215,9 @@ public abstract class AbstractZkLedgerManager implements LedgerManager, Watcher
 
     @Override
     public void process(WatchedEvent event) {
-        LOG.debug("Received watched event {} from zookeeper based ledger manager.", event);
+        if (LOG.isDebugEnabled()) {
+            LOG.debug("Received watched event {} from zookeeper based ledger manager.", event);
+        }
         if (Event.EventType.None == event.getType()) {
             if (Event.KeeperState.Expired == event.getState()) {
                 LOG.info("ZooKeeper client expired on ledger manager.");
@@ -257,10 +254,9 @@ public abstract class AbstractZkLedgerManager implements LedgerManager, Watcher
                     }
                     listeners.remove(ledgerId, listenerSet);
                 }
-            } else {
-                if (LOG.isDebugEnabled()) {
-                    LOG.debug("No ledger metadata listeners to remove from ledger {} after it's deleted.", ledgerId);
-                }
+            } else if (LOG.isDebugEnabled()) {
+                LOG.debug("No ledger metadata listeners to remove from ledger {} after it's deleted.",
+                        ledgerId);
             }
             break;
         case NodeDataChanged:
@@ -383,11 +379,9 @@ public abstract class AbstractZkLedgerManager implements LedgerManager, Watcher
                                     "Remove registered ledger metadata listeners on ledger {} after ledger is deleted.",
                                     ledgerId);
                         }
-                    } else {
-                        if (LOG.isDebugEnabled()) {
-                            LOG.debug("No ledger metadata listeners to remove from ledger {} when it's being deleted.",
-                                    ledgerId);
-                        }
+                    } else if (LOG.isDebugEnabled()) {
+                        LOG.debug("No ledger metadata listeners to remove from ledger {} when it's being deleted.",
+                                ledgerId);
                     }
                     FutureUtils.complete(promise, null);
                 } else {
