@@ -25,8 +25,9 @@ import java.io.File;
 import java.io.IOException;
 import lombok.Setter;
 import lombok.experimental.Accessors;
-import org.apache.bookkeeper.bookie.EntryLogger;
-import org.apache.bookkeeper.bookie.ReadOnlyEntryLogger;
+import org.apache.bookkeeper.bookie.ReadOnlyDefaultEntryLogger;
+import org.apache.bookkeeper.bookie.storage.EntryLogScanner;
+import org.apache.bookkeeper.bookie.storage.EntryLogger;
 import org.apache.bookkeeper.conf.ServerConfiguration;
 import org.apache.bookkeeper.tools.cli.helpers.BookieCommand;
 import org.apache.bookkeeper.tools.framework.CliFlags;
@@ -131,7 +132,7 @@ public class ReadLogCommand extends BookieCommand<ReadLogCommand.ReadLogFlags> {
             File f = new File(flags.filename);
             String name = f.getName();
             if (!name.endsWith(".log")) {
-                LOG.error("Invalid entry log file name " + flags.filename);
+                LOG.error("Invalid entry log file name {}", flags.filename);
                 usage();
                 return false;
             }
@@ -147,8 +148,7 @@ public class ReadLogCommand extends BookieCommand<ReadLogCommand.ReadLogFlags> {
         // scan entry log
         if (startpos != -1) {
             if ((endpos != -1) && (endpos < startpos)) {
-                System.err
-                    .println("ERROR: StartPosition of the range should be lesser than or equal to EndPosition");
+                LOG.error("ERROR: StartPosition of the range should be lesser than or equal to EndPosition");
                 return false;
             }
             scanEntryLogForPositionRange(conf, logId, startpos, endpos, flags.msg);
@@ -172,10 +172,10 @@ public class ReadLogCommand extends BookieCommand<ReadLogCommand.ReadLogFlags> {
     private void scanEntryLogForPositionRange(ServerConfiguration conf, long logId, final long rangeStartPos,
                                               final long rangeEndPos,
                                                 final boolean printMsg) throws Exception {
-        LOG.info("Scan entry log " + logId + " (" + Long.toHexString(logId) + ".log)" + " for PositionRange: "
-                           + rangeStartPos + " - " + rangeEndPos);
+        LOG.info("Scan entry log {} ({}.log) for PositionRange: {} - {}",
+            logId, Long.toHexString(logId), rangeStartPos, rangeEndPos);
         final MutableBoolean entryFound = new MutableBoolean(false);
-        scanEntryLog(conf, logId, new EntryLogger.EntryLogScanner() {
+        scanEntryLog(conf, logId, new EntryLogScanner() {
             private MutableBoolean stopScanning = new MutableBoolean(false);
 
             @Override
@@ -208,11 +208,10 @@ public class ReadLogCommand extends BookieCommand<ReadLogCommand.ReadLogFlags> {
             }
         });
         if (!entryFound.booleanValue()) {
-            LOG.info(
-                "Entry log " + logId + " (" + Long.toHexString(logId) + ".log) doesn't has any entry in the range "
-                + rangeStartPos + " - " + rangeEndPos
-                + ". Probably the position range, you have provided is lesser than the LOGFILE_HEADER_SIZE (1024) "
-                + "or greater than the current log filesize.");
+            LOG.info("Entry log {} ({}.log) doesn't has any entry in the range {} - {}. "
+                + "Probably the position range, you have provided is lesser than the LOGFILE_HEADER_SIZE (1024) "
+                + "or greater than the current log filesize.",
+                logId, Long.toHexString(logId), rangeStartPos, rangeEndPos);
         }
     }
 
@@ -222,7 +221,7 @@ public class ReadLogCommand extends BookieCommand<ReadLogCommand.ReadLogFlags> {
      * @param logId   Entry Log Id
      * @param scanner Entry Log Scanner
      */
-    private void scanEntryLog(ServerConfiguration conf, long logId, EntryLogger.EntryLogScanner scanner)
+    private void scanEntryLog(ServerConfiguration conf, long logId, EntryLogScanner scanner)
         throws IOException {
         initEntryLogger(conf);
         entryLogger.scanEntryLog(logId, scanner);
@@ -231,7 +230,7 @@ public class ReadLogCommand extends BookieCommand<ReadLogCommand.ReadLogFlags> {
     private synchronized void initEntryLogger(ServerConfiguration conf) throws IOException {
         if (null == entryLogger) {
             // provide read only entry logger
-            entryLogger = new ReadOnlyEntryLogger(conf);
+            entryLogger = new ReadOnlyDefaultEntryLogger(conf);
         }
     }
 
@@ -247,10 +246,10 @@ public class ReadLogCommand extends BookieCommand<ReadLogCommand.ReadLogFlags> {
     private void scanEntryLogForSpecificEntry(ServerConfiguration conf, long logId, final long ledgerId,
                                                 final long entryId,
                                                 final boolean printMsg) throws Exception {
-        LOG.info("Scan entry log " + logId + " (" + Long.toHexString(logId) + ".log)" + " for LedgerId "
-                           + ledgerId + ((entryId == -1) ? "" : " for EntryId " + entryId));
+        LOG.info("Scan entry log {} ({}.log) for LedgerId {} {}", logId, Long.toHexString(logId), ledgerId,
+            ((entryId == -1) ? "" : " for EntryId " + entryId));
         final MutableBoolean entryFound = new MutableBoolean(false);
-        scanEntryLog(conf, logId, new EntryLogger.EntryLogScanner() {
+        scanEntryLog(conf, logId, new EntryLogScanner() {
             @Override
             public boolean accept(long candidateLedgerId) {
                 return ((candidateLedgerId == ledgerId) && ((!entryFound.booleanValue()) || (entryId == -1)));
@@ -268,9 +267,8 @@ public class ReadLogCommand extends BookieCommand<ReadLogCommand.ReadLogFlags> {
             }
         });
         if (!entryFound.booleanValue()) {
-            LOG.info("LedgerId " + ledgerId + ((entryId == -1) ? "" : " EntryId " + entryId)
-                               + " is not available in the entry log " + logId + " (" + Long.toHexString(logId)
-                               + ".log)");
+            LOG.info("LedgerId {} {} is not available in the entry log {} ({}.log)",
+                ledgerId, ((entryId == -1) ? "" : " EntryId " + entryId), logId, Long.toHexString(logId));
         }
     }
 
@@ -283,8 +281,8 @@ public class ReadLogCommand extends BookieCommand<ReadLogCommand.ReadLogFlags> {
      *          Whether printing the entry data.
      */
     private void scanEntryLog(ServerConfiguration conf, long logId, final boolean printMsg) throws Exception {
-        LOG.info("Scan entry log " + logId + " (" + Long.toHexString(logId) + ".log)");
-        scanEntryLog(conf, logId, new EntryLogger.EntryLogScanner() {
+        LOG.info("Scan entry log {} ({}.log)", logId, Long.toHexString(logId));
+        scanEntryLog(conf, logId, new EntryLogScanner() {
             @Override
             public boolean accept(long ledgerId) {
                 return true;
