@@ -62,6 +62,11 @@ public class GenerateCookieCommand extends CookieCommand<Flags> {
             required = true)
         private String ledgerDirs;
 
+        @Parameter(
+                names = { "-ix", "--index-dirs" },
+                description = "The index directories used by this bookie")
+        private String indexDirs = null;
+
         @Parameter(
             names = { "-i", "--instance-id" },
             description = "The instance id of the cluster that this bookie belongs to."
@@ -118,7 +123,9 @@ public class GenerateCookieCommand extends CookieCommand<Flags> {
         }
         builder.setJournalDirs(cmdFlags.journalDirs);
         builder.setLedgerDirs(Cookie.encodeDirPaths(cmdFlags.ledgerDirs.split(",")));
-
+        if (StringUtils.isNotBlank(cmdFlags.indexDirs)) {
+            builder.setIndexDirs(Cookie.encodeDirPaths(cmdFlags.indexDirs.split(",")));
+        }
         Cookie cookie = builder.build();
         cookie.writeToFile(new File(cmdFlags.outputFile));
         spec.console().println("Successfully saved the generated cookie to " + cmdFlags.outputFile);
