@@ -30,16 +30,15 @@ import static org.junit.Assert.fail;
 import io.netty.buffer.ByteBuf;
 import io.netty.buffer.ByteBufAllocator;
 import io.netty.buffer.Unpooled;
-
 import java.io.File;
 import java.io.IOException;
 import java.util.ArrayList;
 import java.util.List;
+import java.util.concurrent.CountDownLatch;
 import java.util.concurrent.LinkedBlockingQueue;
 import java.util.concurrent.atomic.AtomicBoolean;
 import java.util.concurrent.atomic.AtomicInteger;
 import java.util.concurrent.atomic.AtomicLong;
-
 import org.apache.bookkeeper.bookie.Bookie.NoLedgerException;
 import org.apache.bookkeeper.bookie.CheckpointSource.Checkpoint;
 import org.apache.bookkeeper.bookie.FileInfoBackingCache.CachedFileInfo;
@@ -352,7 +351,7 @@ public class LedgerCacheTest {
                 // this is fine, means the ledger was written to the index cache, but not
                 // the entry log
             } catch (IOException ioe) {
-                if (ioe.getCause() instanceof EntryLogger.EntryLookupException) {
+                if (ioe.getCause() instanceof DefaultEntryLogger.EntryLookupException) {
                     // this is fine, means the ledger was not fully written to
                     // the entry log
                 } else {
@@ -799,13 +798,17 @@ public class LedgerCacheTest {
         // after flush failure, the bookie is set to readOnly
         assertTrue("Bookie is expected to be in Read mode", bookie.isReadOnly());
         // write fail
+        CountDownLatch latch = new CountDownLatch(1);
         bookie.addEntry(generateEntry(1, 3), false, new BookkeeperInternalCallbacks.WriteCallback(){
             public void writeComplete(int rc, long ledgerId, long entryId, BookieId addr, Object ctx){
-                LOG.info("fail write to bk");
-                assertTrue(rc != OK);
+                LOG.info("Write to bk succeed due to the bookie readOnly mode check is in the request parse step. "
+                    + "In the addEntry step, we won't check bookie's mode");
+                assertEquals(OK, rc);
+                latch.countDown();
             }
 
         }, null, "passwd".getBytes());
+        latch.await();
         bookie.shutdown();
 
     }
