@@ -27,7 +27,6 @@ import static org.mockito.Mockito.mock;
 import io.netty.buffer.ByteBuf;
 import io.netty.buffer.Unpooled;
 import io.netty.buffer.UnpooledByteBufAllocator;
-
 import java.io.IOException;
 import java.util.concurrent.CountDownLatch;
 import java.util.concurrent.LinkedBlockingQueue;
@@ -224,12 +223,11 @@ public class SortedLedgerStorageCheckpointTest extends LedgerStorageTestBase {
         });
 
         // simulate entry log is rotated (due to compaction)
-        EntryLogManagerForSingleEntryLog entryLogManager = (EntryLogManagerForSingleEntryLog) storage.getEntryLogger()
-                .getEntryLogManager();
-        entryLogManager.createNewLog(EntryLogger.UNASSIGNED_LEDGERID);
-        long leastUnflushedLogId = storage.getEntryLogger().getLeastUnflushedLogId();
+        DefaultEntryLogger elogger = storage.getEntryLogger();
+        EntryLogManagerForSingleEntryLog entryLogManager =
+            (EntryLogManagerForSingleEntryLog) elogger.getEntryLogManager();
+        entryLogManager.createNewLog(DefaultEntryLogger.UNASSIGNED_LEDGERID);
         long currentLogId = entryLogManager.getCurrentLogId();
-        log.info("Least unflushed entry log : current = {}, leastUnflushed = {}", currentLogId, leastUnflushedLogId);
 
         readyLatch.countDown();
         assertNull(checkpoints.poll());
@@ -246,8 +244,8 @@ public class SortedLedgerStorageCheckpointTest extends LedgerStorageTestBase {
         assertEquals(0, storage.memTable.kvmap.size());
         assertTrue(
             "current log " + currentLogId + " contains entries added from memtable should be forced to disk"
-            + " but least unflushed log is " + storage.getEntryLogger().getLeastUnflushedLogId(),
-            storage.getEntryLogger().getLeastUnflushedLogId() > currentLogId);
+            + " but flushed logs are " + elogger.getFlushedLogIds(),
+            elogger.getFlushedLogIds().contains(currentLogId));
     }
 
 }
