@@ -33,7 +33,7 @@ import static org.mockito.Mockito.when;
 import io.netty.buffer.ByteBuf;
 import io.netty.buffer.Unpooled;
 import io.netty.buffer.UnpooledByteBufAllocator;
-
+import io.netty.util.ReferenceCounted;
 import java.util.ArrayList;
 import java.util.Collections;
 import java.util.HashMap;
@@ -167,10 +167,15 @@ public class ReadLastConfirmedAndEntryOpTest {
         final long lac = 1L;
 
         ByteBuf data = Unpooled.copiedBuffer("test-speculative-responses", UTF_8);
-        ByteBufList dataWithDigest = digestManager.computeDigestAndPackageForSending(
-            entryId, lac, data.readableBytes(), data);
-        byte[] bytesWithDigest = new byte[dataWithDigest.readableBytes()];
-        assertEquals(bytesWithDigest.length, dataWithDigest.getBytes(bytesWithDigest));
+        ReferenceCounted refCnt = digestManager.computeDigestAndPackageForSending(
+            entryId, lac, data.readableBytes(), data, new byte[20], 0);
+
+        byte[] bytesWithDigest = null;
+        if (refCnt instanceof ByteBufList) {
+            ByteBufList dataWithDigest = (ByteBufList) refCnt;
+            bytesWithDigest = new byte[dataWithDigest.readableBytes()];
+            assertEquals(bytesWithDigest.length, dataWithDigest.getBytes(bytesWithDigest));
+        }
 
         final Map<BookieId, ReadLastConfirmedAndEntryHolder> callbacks =
             Collections.synchronizedMap(new HashMap<>());
