@@ -1,4 +1,4 @@
-/**
+/*
  * Licensed to the Apache Software Foundation (ASF) under one
  * or more contributor license agreements.  See the NOTICE file
  * distributed with this work for additional information
@@ -40,7 +40,6 @@ import org.apache.bookkeeper.stats.Counter;
 import org.apache.bookkeeper.stats.NullStatsLogger;
 import org.apache.bookkeeper.stats.OpStatsLogger;
 import org.apache.bookkeeper.stats.StatsLogger;
-import org.apache.bookkeeper.util.SafeRunnable;
 import org.apache.commons.lang3.tuple.Pair;
 import org.apache.distributedlog.DistributedLogConstants;
 import org.apache.distributedlog.ZooKeeperClient;
@@ -393,25 +392,22 @@ class ZKSessionLock implements SessionLock {
      *          function to execute a lock action
      */
     protected void executeLockAction(final int lockEpoch, final LockAction func) {
-        lockStateExecutor.executeOrdered(lockPath, new SafeRunnable() {
-            @Override
-            public void safeRun() {
-                if (getEpoch() == lockEpoch) {
-                    if (LOG.isTraceEnabled()) {
-                        LOG.trace("{} executing lock action '{}' under epoch {} for lock {}",
+        lockStateExecutor.executeOrdered(lockPath, () -> {
+            if (getEpoch() == lockEpoch) {
+                if (LOG.isTraceEnabled()) {
+                    LOG.trace("{} executing lock action '{}' under epoch {} for lock {}",
                             lockId, func.getActionName(), lockEpoch, lockPath);
-                    }
-                    func.execute();
-                    if (LOG.isTraceEnabled()) {
-                        LOG.trace("{} executed lock action '{}' under epoch {} for lock {}",
+                }
+                func.execute();
+                if (LOG.isTraceEnabled()) {
+                    LOG.trace("{} executed lock action '{}' under epoch {} for lock {}",
                             lockId, func.getActionName(), lockEpoch, lockPath);
-                    }
-                } else {
-                    if (LOG.isTraceEnabled()) {
-                        LOG.trace("{} skipped executing lock action '{}' for lock {},"
-                                        + " since epoch is changed from {} to {}.",
+                }
+            } else {
+                if (LOG.isTraceEnabled()) {
+                    LOG.trace("{} skipped executing lock action '{}' for lock {},"
+                                    + " since epoch is changed from {} to {}.",
                             lockId, func.getActionName(), lockPath, lockEpoch, getEpoch());
-                    }
                 }
             }
         });
@@ -431,28 +427,25 @@ class ZKSessionLock implements SessionLock {
      */
     protected <T> void executeLockAction(final int lockEpoch,
                                          final LockAction func, final CompletableFuture<T> promise) {
-        lockStateExecutor.executeOrdered(lockPath, new SafeRunnable() {
-            @Override
-            public void safeRun() {
-                int currentEpoch = getEpoch();
-                if (currentEpoch == lockEpoch) {
-                    if (LOG.isTraceEnabled()) {
-                        LOG.trace("{} executed lock action '{}' under epoch {} for lock {}",
+        lockStateExecutor.executeOrdered(lockPath, () -> {
+            int currentEpoch = getEpoch();
+            if (currentEpoch == lockEpoch) {
+                if (LOG.isTraceEnabled()) {
+                    LOG.trace("{} executed lock action '{}' under epoch {} for lock {}",
                             lockId, func.getActionName(), lockEpoch, lockPath);
-                    }
-                    func.execute();
-                    if (LOG.isTraceEnabled()) {
-                        LOG.trace("{} executed lock action '{}' under epoch {} for lock {}",
-                            lockId, func.getActionName(), lockEpoch, lockPath);
-                    }
-                } else {
-                    if (LOG.isTraceEnabled()) {
-                        LOG.trace("{} skipped executing lock action '{}' for lock {},"
-                                        + " since epoch is changed from {} to {}.",
-                            lockId, func.getActionName(), lockPath, lockEpoch, currentEpoch);
-                    }
-                    promise.completeExceptionally(new EpochChangedException(lockPath, lockEpoch, currentEpoch));
                 }
+                func.execute();
+                if (LOG.isTraceEnabled()) {
+                    LOG.trace("{} executed lock action '{}' under epoch {} for lock {}",
+                            lockId, func.getActionName(), lockEpoch, lockPath);
+                }
+            } else {
+                if (LOG.isTraceEnabled()) {
+                    LOG.trace("{} skipped executing lock action '{}' for lock {},"
+                                    + " since epoch is changed from {} to {}.",
+                            lockId, func.getActionName(), lockPath, lockEpoch, currentEpoch);
+                }
+                promise.completeExceptionally(new EpochChangedException(lockPath, lockEpoch, currentEpoch));
             }
         });
     }
@@ -554,40 +547,37 @@ class ZKSessionLock implements SessionLock {
                 @Override
                 public void processResult(final int rc, String path, Object ctx,
                                           final List<String> children, Stat stat) {
-                    lockStateExecutor.executeOrdered(lockPath, new SafeRunnable() {
-                        @Override
-                        public void safeRun() {
-                            if (!lockState.inState(State.INIT)) {
-                                result.completeExceptionally(new LockStateChangedException(lockPath,
-                                        lockId, State.INIT, lockState.getState()));
-                                return;
-                            }
-                            if (KeeperException.Code.OK.intValue() != rc) {
-                                result.completeExceptionally(KeeperException.create(KeeperException.Code.get(rc)));
-                                return;
-                            }
+                    lockStateExecutor.executeOrdered(lockPath, () -> {
+                        if (!lockState.inState(State.INIT)) {
+                            result.completeExceptionally(new LockStateChangedException(lockPath,
+                                    lockId, State.INIT, lockState.getState()));
+                            return;
+                        }
+                        if (KeeperException.Code.OK.intValue() != rc) {
+                            result.completeExceptionally(KeeperException.create(KeeperException.Code.get(rc)));
+                            return;
+                        }
 
-                            FailpointUtils.checkFailPointNoThrow(FailpointUtils.FailPointName.FP_LockTryAcquire);
+                        FailpointUtils.checkFailPointNoThrow(FailpointUtils.FailPointName.FP_LockTryAcquire);
 
-                            Collections.sort(children, MEMBER_COMPARATOR);
-                            if (children.size() > 0) {
-                                asyncParseClientID(zk, lockPath, children.get(0)).whenCompleteAsync(
-                                        new FutureEventListener<Pair<String, Long>>() {
-                                            @Override
-                                            public void onSuccess(Pair<String, Long> owner) {
-                                                if (!checkOrClaimLockOwner(owner, result)) {
-                                                    acquireFuture.complete(false);
-                                                }
+                        Collections.sort(children, MEMBER_COMPARATOR);
+                        if (children.size() > 0) {
+                            asyncParseClientID(zk, lockPath, children.get(0)).whenCompleteAsync(
+                                    new FutureEventListener<Pair<String, Long>>() {
+                                        @Override
+                                        public void onSuccess(Pair<String, Long> owner) {
+                                            if (!checkOrClaimLockOwner(owner, result)) {
+                                                acquireFuture.complete(false);
                                             }
+                                        }
 
-                                            @Override
-                                            public void onFailure(final Throwable cause) {
-                                                result.completeExceptionally(cause);
-                                            }
-                                        }, lockStateExecutor.chooseThread(lockPath));
-                            } else {
-                                asyncTryLock(wait, result);
-                            }
+                                        @Override
+                                        public void onFailure(final Throwable cause) {
+                                            result.completeExceptionally(cause);
+                                        }
+                                    }, lockStateExecutor.chooseThread(lockPath));
+                        } else {
+                            asyncTryLock(wait, result);
                         }
                     });
                 }
@@ -648,12 +638,7 @@ class ZKSessionLock implements SessionLock {
     private boolean checkOrClaimLockOwner(final Pair<String, Long> currentOwner,
                                           final CompletableFuture<String> result) {
         if (lockId.compareTo(currentOwner) != 0 && !lockContext.hasLockId(currentOwner)) {
-            lockStateExecutor.executeOrdered(lockPath, new SafeRunnable() {
-                @Override
-                public void safeRun() {
-                    result.complete(currentOwner.getLeft());
-                }
-            });
+            lockStateExecutor.executeOrdered(lockPath, () -> result.complete(currentOwner.getLeft()));
             return false;
         }
         // current owner is itself
@@ -878,13 +863,10 @@ class ZKSessionLock implements SessionLock {
         // Use lock executor here rather than lock action, because we want this opertaion to be applied
         // whether the epoch has changed or not. The member node is EPHEMERAL_SEQUENTIAL so there's no
         // risk of an ABA problem where we delete and recreate a node and then delete it again here.
-        lockStateExecutor.executeOrdered(lockPath, new SafeRunnable() {
-            @Override
-            public void safeRun() {
-                acquireFuture.completeExceptionally(cause);
-                unlockInternal(promise);
-                promise.whenComplete(new OpStatsListener<Void>(unlockStats));
-            }
+        lockStateExecutor.executeOrdered(lockPath, () -> {
+            acquireFuture.completeExceptionally(cause);
+            unlockInternal(promise);
+            promise.whenComplete(new OpStatsListener<Void>(unlockStats));
         });
 
         return promise;
@@ -978,23 +960,20 @@ class ZKSessionLock implements SessionLock {
         zk.delete(currentNode, -1, new AsyncCallback.VoidCallback() {
             @Override
             public void processResult(final int rc, final String path, Object ctx) {
-                lockStateExecutor.executeOrdered(lockPath, new SafeRunnable() {
-                    @Override
-                    public void safeRun() {
-                        if (KeeperException.Code.OK.intValue() == rc) {
-                            LOG.info("Deleted lock node {} for {} successfully.", path, lockId);
-                        } else if (KeeperException.Code.NONODE.intValue() == rc
-                                || KeeperException.Code.SESSIONEXPIRED.intValue() == rc) {
-                            LOG.info("Delete node failed. Node already gone for node {} id {}, rc = {}",
+                lockStateExecutor.executeOrdered(lockPath, () -> {
+                    if (KeeperException.Code.OK.intValue() == rc) {
+                        LOG.info("Deleted lock node {} for {} successfully.", path, lockId);
+                    } else if (KeeperException.Code.NONODE.intValue() == rc
+                            || KeeperException.Code.SESSIONEXPIRED.intValue() == rc) {
+                        LOG.info("Delete node failed. Node already gone for node {} id {}, rc = {}",
                                 path, lockId, KeeperException.Code.get(rc));
-                        } else {
-                            LOG.error("Failed on deleting lock node {} for {} : {}",
+                    } else {
+                        LOG.error("Failed on deleting lock node {} for {} : {}",
                                 path, lockId, KeeperException.Code.get(rc));
-                        }
-
-                        FailpointUtils.checkFailPointNoThrow(FailpointUtils.FailPointName.FP_LockUnlockCleanup);
-                        promise.complete(null);
                     }
+
+                    FailpointUtils.checkFailPointNoThrow(FailpointUtils.FailPointName.FP_LockUnlockCleanup);
+                    promise.complete(null);
                 });
             }
         }, null);
@@ -1324,8 +1303,10 @@ class ZKSessionLock implements SessionLock {
 
         @Override
         public void process(WatchedEvent event) {
-            LOG.debug("Received event {} from lock {} at {} : watcher epoch {}, lock epoch {}.",
-                event, lockPath, System.currentTimeMillis(), epoch, getEpoch());
+            if (LOG.isDebugEnabled()) {
+                LOG.debug("Received event {} from lock {} at {} : watcher epoch {}, lock epoch {}.",
+                        event, lockPath, System.currentTimeMillis(), epoch, getEpoch());
+            }
             if (event.getType() == Watcher.Event.EventType.None) {
                 switch (event.getState()) {
                     case SyncConnected:
