@@ -33,6 +33,8 @@ import static org.apache.bookkeeper.statelib.impl.rocksdb.RocksConstants.WRITE_B
 import com.google.common.annotations.VisibleForTesting;
 import com.google.common.collect.Lists;
 import com.google.common.collect.Sets;
+import com.google.common.io.MoreFiles;
+import com.google.common.io.RecursiveDeleteOption;
 import com.google.common.primitives.SignedBytes;
 import java.io.File;
 import java.io.IOException;
@@ -46,6 +48,7 @@ import java.util.NoSuchElementException;
 import java.util.Set;
 import java.util.UUID;
 import java.util.concurrent.ScheduledExecutorService;
+import java.util.concurrent.TimeoutException;
 import java.util.concurrent.atomic.AtomicLongFieldUpdater;
 import lombok.AccessLevel;
 import lombok.RequiredArgsConstructor;
@@ -63,6 +66,7 @@ import org.apache.bookkeeper.statelib.api.kv.KVMulti;
 import org.apache.bookkeeper.statelib.api.kv.KVStore;
 import org.apache.bookkeeper.statelib.impl.Bytes;
 import org.apache.bookkeeper.statelib.impl.rocksdb.RocksUtils;
+import org.apache.bookkeeper.statelib.impl.rocksdb.checkpoint.CheckpointInfo;
 import org.apache.bookkeeper.statelib.impl.rocksdb.checkpoint.RocksCheckpointer;
 import org.apache.commons.lang3.tuple.Pair;
 import org.rocksdb.BlockBasedTableConfig;
@@ -73,9 +77,11 @@ import org.rocksdb.ColumnFamilyOptions;
 import org.rocksdb.DBOptions;
 import org.rocksdb.FlushOptions;
 import org.rocksdb.LRUCache;
+import org.rocksdb.Options;
 import org.rocksdb.RocksDB;
 import org.rocksdb.RocksDBException;
 import org.rocksdb.RocksIterator;
+import org.rocksdb.TtlDB;
 import org.rocksdb.WriteBatch;
 import org.rocksdb.WriteOptions;
 
@@ -89,7 +95,12 @@ import org.rocksdb.WriteOptions;
 public class RocksdbKVStore<K, V> implements KVStore<K, V> {
 
     private static final byte[] METADATA_CF = ".meta".getBytes(UTF_8);
+
+    // Use a separate column family when a TTL is set so that we can't (easily) open a TTL
+    // enabled DB with the old code.
     private static final byte[] DATA_CF = "default".getBytes(UTF_8);
+    private static final byte[] DATA_TTL_CF = "default_ttl".getBytes(UTF_8);
+
     private static final byte[] LAST_REVISION = ".lrev".getBytes(UTF_8);
 
     private static final AtomicLongFieldUpdater<RocksdbKVStore> lastRevisionUpdater =
@@ -97,6 +108,7 @@ public class RocksdbKVStore<K, V> implements KVStore<K, V> {
 
     // parameters for the store
     protected String name;
+    protected int ttlSeconds;
     protected Coder<K> keyCoder;
     protected Coder<V> valCoder;
 
@@ -131,6 +143,8 @@ public class RocksdbKVStore<K, V> implements KVStore<K, V> {
         RocksDB.loadLibrary();
     }
 
+    private boolean cleanupLocalStoreDirEnable;
+
     public RocksdbKVStore() {
         // initialize the iterators set
         this.kvIters = Collections.synchronizedSet(Sets.newHashSet());
@@ -164,7 +178,23 @@ public class RocksdbKVStore<K, V> implements KVStore<K, V> {
         String dbName = spec.getName();
         File localStorePath = spec.getLocalStateStoreDir();
 
-        RocksCheckpointer.restore(dbName, localStorePath, spec.getCheckpointStore());
+        List<CheckpointInfo> checkpoints = RocksCheckpointer.getCheckpoints(dbName, spec.getCheckpointStore());
+        for (CheckpointInfo cpi : checkpoints) {
+            try {
+                cpi.restore(dbName, localStorePath, spec.getCheckpointStore(), spec.getCheckpointRestoreIdleLimit());
+                openRocksdb(spec);
+                checkpoints.stream()
+                    .filter(cp -> cp != cpi) // ignore the current restored checkpoint
+                    .forEach(cp -> cp.remove(localStorePath)); // delete everything else
+                break;
+            } catch (TimeoutException e) {
+                log.error("Timeout waiting for checkpoint restore: {}", cpi, e);
+                throw new StateStoreException("Failed to restore checkpoint: " + cpi.getId(), e);
+            } catch (StateStoreException e) {
+                // Got an exception. Log and try the next checkpoint
+                log.error("Failed to restore checkpoint: {}", cpi, e);
+            }
+        }
     }
 
     @Override
@@ -239,20 +269,26 @@ public class RocksdbKVStore<K, V> implements KVStore<K, V> {
         checkNotNull(spec.getLocalStateStoreDir(),
             "local state store directory is not configured");
 
-        checkpointStore = spec.getCheckpointStore();
-        if (null != checkpointStore) {
-            // load checkpoint from checkpoint store
-            loadRocksdbFromCheckpointStore(spec);
-        }
-
         this.name = spec.getName();
 
+        this.cleanupLocalStoreDirEnable = spec.isLocalStorageCleanupEnable();
+        this.ttlSeconds = spec.getTtlSeconds();
+
         // initialize the coders
         this.keyCoder = (Coder<K>) spec.getKeyCoder();
         this.valCoder = (Coder<V>) spec.getValCoder();
 
-        // open the rocksdb
-        openRocksdb(spec);
+        cleanupLocalStoreDir(spec.getLocalStateStoreDir());
+
+        checkpointStore = spec.getCheckpointStore();
+        if (null != checkpointStore) {
+            // load checkpoint from checkpoint store
+            loadRocksdbFromCheckpointStore(spec);
+        } else {
+            // open the rocksdb
+            openRocksdb(spec);
+        }
+
 
         // once the rocksdb is opened, read the last revision
         readLastRevision();
@@ -264,7 +300,9 @@ public class RocksdbKVStore<K, V> implements KVStore<K, V> {
                 db,
                 checkpointStore,
                 true,
-                true);
+                true,
+                spec.isCheckpointChecksumEnable(),
+                spec.isCheckpointChecksumCompatible());
             checkpointScheduler = spec.getCheckpointIOScheduler();
         }
 
@@ -321,18 +359,20 @@ public class RocksdbKVStore<K, V> implements KVStore<K, V> {
         return openRocksdb(dir, options, cfOpts);
     }
 
-    protected static Pair<RocksDB, List<ColumnFamilyHandle>> openRocksdb(
+    protected Pair<RocksDB, List<ColumnFamilyHandle>> openRocksdb(
         File dir, DBOptions options, ColumnFamilyOptions cfOpts)
         throws StateStoreException {
-        // make sure the db directory's parent dir is created
-        ColumnFamilyDescriptor metaDesc = new ColumnFamilyDescriptor(METADATA_CF, cfOpts);
-        ColumnFamilyDescriptor dataDesc = new ColumnFamilyDescriptor(DATA_CF, cfOpts);
+        final boolean haveTtl = ttlSeconds != 0;
+        final ColumnFamilyDescriptor metaDesc = new ColumnFamilyDescriptor(METADATA_CF, cfOpts);
+        final ColumnFamilyDescriptor dataDesc = new ColumnFamilyDescriptor(haveTtl ? DATA_TTL_CF : DATA_CF, cfOpts);
 
         try {
+            // make sure the db directory's parent dir is created
             Files.createDirectories(dir.toPath());
             File dbDir = new File(dir, "current");
 
-            if (!dbDir.exists()) {
+            final boolean dbExists = dbDir.exists();
+            if (!dbExists) {
                 // empty state
                 String uuid = UUID.randomUUID().toString();
                 Path checkpointPath = Paths.get(dir.getAbsolutePath(), "checkpoints", uuid);
@@ -340,14 +380,36 @@ public class RocksdbKVStore<K, V> implements KVStore<K, V> {
                 Files.createSymbolicLink(
                     Paths.get(dbDir.getAbsolutePath()),
                     checkpointPath);
+            } else {
+                // For an existing database, ensure we open with a TTL if it was created that way: values in a TTLDB
+                // are prefixed with the ttl, and therefore incompatible with a plain RocksDB.  If the new TTL value
+                // does not match the previous TTL, it will apply to any new or updated keys
+
+                try (Options opts = new org.rocksdb.Options(options, cfOpts)) {
+                    byte[] wanted = haveTtl ? DATA_TTL_CF : DATA_CF;
+                    byte[] other = haveTtl ? DATA_CF : DATA_TTL_CF;
+                    List<byte[]> cfNames = RocksDB.listColumnFamilies(opts, dbDir.getAbsolutePath());
+                    if (!cfNames.contains(wanted) && cfNames.contains(other)) {
+                        throw new StateStoreException(String.format("{}: expected {} column family, found {}",
+                                dbDir.getAbsolutePath(), wanted, other));
+                    }
+                }
             }
 
             List<ColumnFamilyHandle> cfHandles = Lists.newArrayListWithExpectedSize(2);
-            RocksDB db = RocksDB.open(
-                options,
-                dbDir.getAbsolutePath(),
-                Lists.newArrayList(metaDesc, dataDesc),
-                cfHandles);
+            final RocksDB db = haveTtl
+                    ? TtlDB.open(
+                        options,
+                        dbDir.getAbsolutePath(),
+                        Lists.newArrayList(metaDesc, dataDesc),
+                        cfHandles,
+                        Lists.newArrayList(0, ttlSeconds),
+                        false)
+                    : RocksDB.open(
+                        options,
+                        dbDir.getAbsolutePath(),
+                        Lists.newArrayList(metaDesc, dataDesc),
+                        cfHandles);
             return Pair.of(db, cfHandles);
         } catch (IOException ioe) {
             log.error("Failed to create parent directory {} for opening rocksdb", dir.getParentFile().toPath(), ioe);
@@ -392,6 +454,20 @@ public class RocksdbKVStore<K, V> implements KVStore<K, V> {
         RocksUtils.close(writeOpts);
         RocksUtils.close(flushOpts);
         RocksUtils.close(cfOpts);
+
+        cleanupLocalStoreDir(dbDir);
+    }
+
+    private void cleanupLocalStoreDir(File dbDir) {
+        if (cleanupLocalStoreDirEnable) {
+            if (dbDir.exists()) {
+                try {
+                    MoreFiles.deleteRecursively(dbDir.toPath(), RecursiveDeleteOption.ALLOW_INSECURE);
+                } catch (IOException e) {
+                    log.error("Failed to cleanup localStoreDir", e);
+                }
+            }
+        }
     }
 
     protected void closeLocalDB() {
