@@ -39,6 +39,8 @@ import org.apache.bookkeeper.statelib.api.mvcc.MVCCAsyncStore;
 import org.apache.bookkeeper.statelib.impl.rocksdb.checkpoint.fs.FSCheckpointManager;
 import org.apache.bookkeeper.stream.storage.StorageResources;
 import org.apache.bookkeeper.stream.storage.StorageResourcesSpec;
+import org.apache.bookkeeper.stream.storage.conf.StorageConfiguration;
+import org.apache.commons.configuration.CompositeConfiguration;
 import org.apache.distributedlog.DLSN;
 import org.apache.distributedlog.LogRecord;
 import org.apache.distributedlog.LogRecordWithDLSN;
@@ -65,6 +67,11 @@ public class MVCCStoreFactoryImplTest {
     private StorageResources resources;
     private MVCCStoreFactoryImpl factory;
 
+    private final CompositeConfiguration compConf =
+        new CompositeConfiguration();
+    private final StorageConfiguration storageConf =
+        new StorageConfiguration(compConf);
+
     @Before
     public void setup() throws IOException {
         this.namespace = mock(Namespace.class);
@@ -103,7 +110,7 @@ public class MVCCStoreFactoryImplTest {
             () -> new FSCheckpointManager(new File(storeDirs[0], "checkpoints")),
             storeDirs,
             resources,
-            false);
+            false, storageConf);
     }
 
     @Test
@@ -113,7 +120,7 @@ public class MVCCStoreFactoryImplTest {
         long rangeId = streamId + 1;
 
         try (MVCCAsyncStore<byte[], byte[]> store = FutureUtils.result(
-            factory.openStore(scId, streamId, rangeId))) {
+            factory.openStore(scId, streamId, rangeId, 0))) {
 
             log.info("Open store (scId = {}, streamId = {}, rangeId = {}) to test",
                 scId, streamId, rangeId);
@@ -140,13 +147,13 @@ public class MVCCStoreFactoryImplTest {
             assertTrue(store.spec().getKeyCoder() instanceof ByteArrayCoder);
             assertTrue(store.spec().getValCoder() instanceof ByteArrayCoder);
             assertSame(
-                factory.writeIOScheduler().chooseThread(streamId % 3),
+                factory.writeIOScheduler().chooseThread(streamId),
                 store.spec().getWriteIOScheduler());
             assertSame(
-                factory.readIOScheduler().chooseThread(streamId % 3),
+                factory.readIOScheduler().chooseThread(streamId),
                 store.spec().getReadIOScheduler());
             assertSame(
-                factory.checkpointScheduler().chooseThread(streamId % 3),
+                factory.checkpointScheduler().chooseThread(streamId),
                 store.spec().getCheckpointIOScheduler());
             assertTrue(store.spec().getCheckpointStore() instanceof FSCheckpointManager);
             assertEquals(Duration.ofMinutes(15), store.spec().getCheckpointDuration());
